@@ -239,8 +239,12 @@ void command_print(gpointer callback_data,guint callback_action,
 	ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	printer.select=ptw->select.x>=0;
 	printer.column=ptw->margin;
-	print_dialog(&printer);
+	printer.fontwidth=ptw->fontwidth;
+	printer.fontheight=ptw->fontheight;
+	if (print_dialog(&printer))
+		print_out(ptw,&printer);
 }
 #endif
 
