@@ -224,65 +224,53 @@ void conf_dialog(void)
 	gtk_signal_connect(GTK_OBJECT(radio3),"toggled",conf_dialog_toggled,NULL);
 	/* ե졼ȥܥå */
 	frame0=gtk_frame_new(_("ɥΥ"));
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox0=gtk_hbox_new(FALSE,0);
+	hbox0=gtk_hbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox0),8);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),label1,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin1,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),label2,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin2,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	gtk_container_add(GTK_CONTAINER(frame0),vbox);
+	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
+	gtk_container_add(GTK_CONTAINER(frame0),hbox0);
 
 	frame1=gtk_frame_new(_("֤ΰ"));
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox0=gtk_hbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	hbox0=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_start(GTK_BOX(hbox0),radio0,TRUE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),radio1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox0),radio2,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
+	hbox0=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),radio1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox0),radio2,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
 	hbox0=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),radio3,TRUE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame1),vbox);
 
-	vbox=gtk_vbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
 	hbox0=gtk_hbox_new(FALSE,0);
-	hbox1=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox1),label0,FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox1),spin0,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),check0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),check1,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),frame0,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),label0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),spin0,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),check0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),check1,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),frame0,FALSE,FALSE,0);
 
-	hbox1=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox1),vbox,TRUE,TRUE,8);
+	hbox0=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),vbox,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),frame1,TRUE,TRUE,0);
 
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),frame1,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox1),vbox,TRUE,TRUE,8);
-
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox0),button1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox0),button0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox1,TRUE,TRUE,8);
-	gtk_box_pack_end(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,TRUE,TRUE,0);
+	hbox0=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox0),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox0),button0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
 	/* ɽ */
