@@ -144,33 +144,32 @@ gboolean find_dialog(FIND *fd)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fd->arrow?radio1:radio0),
 																		TRUE);
 	/* ե졼ȥܥå */
-	tbox=gtk_vbox_new(FALSE,0);
+	tbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(tbox),8);
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),
-								gtk_label_new(_("ʸ")),FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),combo,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,8);
+								gtk_label_new(_("ʸ")),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),combo,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
 	frame0=gtk_frame_new(_("ץ"));
-	hbox=gtk_hbox_new(FALSE,0);
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame0),hbox);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame0),vbox);
 	frame1=gtk_frame_new(_(""));
-	hbox=gtk_hbox_new(FALSE,0);
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),radio1,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame1),hbox);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),frame0,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),frame1,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(tbox),hbox,FALSE,FALSE,8);
+	vbox=gtk_vbox_new(FALSE,7);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),radio1,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame1),vbox);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),frame0,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),frame1,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),tbox);
 
 	/* ɽ */
