@@ -229,18 +229,17 @@ void format_dialog(void)
 	GTK_WIDGET_SET_FLAGS(button4,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button5,GTK_CAN_DEFAULT);
 	/* ܥå */
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),scroll,TRUE,TRUE,8);
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),button3,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),button4,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button5,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,8);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),button3,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),button4,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button5,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
 	/* ɽ */
