@@ -16,9 +16,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "print.h"
 #ifdef USE_GDKPIXBUF
+#include <gdk/gdkkeysyms.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <stdio.h>
+#include "abort.h"
+#include "charset.h"
+#include "edit.h"
+#include "other.h"
 
 
 PRNCFG printer;						/*  */
@@ -26,11 +32,11 @@ PRNCFG printer;						/*  */
 
 /******************************************************************************
 *                                                                             *
-* ؿ                                                                  *
+* ؿ                                                        *
 *                                                                             *
 ******************************************************************************/
 static gboolean print_clicked_ok;
-static GtkWidget *dialog,*button0,*button1,*entry0,*entry1,*radio0;
+static GtkWidget *dialog,*button0,*button1,*check,*entry0,*entry1,*radio0;
 static GtkWidget *label1,*label2,*label3;
 static GtkWidget *spin0,*spin1,*spin2,*spin3,*spin4,*spin5,*spin6;
 static struct {
@@ -41,26 +47,53 @@ static struct {
 
 
 /* OKܥɽ/ɽȽ */
-static void print_dialog_ok_sensitive(GtkWidget *widget,gpointer user_data)
+static void print_dialog_ok_sensitive(GtkWidget *widget,PRNCFG *prncfg)
 {
-	gint left,top,right,bottom;
+	gint column,row,width,height,left,top,right,bottom;
 
+	column=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
+	width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
+	height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
 	top=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin3));
 	left=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin4));
 	right=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin5));
 	bottom=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin6));
-	gtk_widget_set_sensitive(button1,
-	strlen(gtk_entry_get_text(GTK_ENTRY(gtk_toggle_button_get_active(
-								GTK_TOGGLE_BUTTON(radio0))?entry0:entry1)))>0
-	&& gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0))>=2
-	&& left>=0 && top>=0 && right>=0 && bottom>=0
-	&& gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1))>left+right
-	&& gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2))>top+bottom);
+	width-=left+right;
+	height-=top+bottom;
+	row=left>=0 && top>=0 && right>=0 && bottom>=0 && width>0 && height>0
+				?column*prncfg->fontwidth*height/(width*prncfg->fontheight):0;
+	gtk_widget_set_sensitive(button1,column>=1 && row>=1
+		&& strlen(gtk_entry_get_text(GTK_ENTRY(gtk_toggle_button_get_active(
+								GTK_TOGGLE_BUTTON(radio0))?entry0:entry1)))>0);
+}
+
+
+/* ԥܥѲ */
+static void print_dialog_changed_spin(GtkWidget *widget,PRNCFG *prncfg)
+{
+	gchar *text;
+	gint column,row,width,height,left,top,right,bottom;
+
+	column=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
+	width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
+	height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
+	top=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin3));
+	left=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin4));
+	right=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin5));
+	bottom=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin6));
+	width-=left+right;
+	height-=top+bottom;
+	row=left>=0 && top>=0 && right>=0 && bottom>=0 && width>0 && height>0
+				?column*prncfg->fontwidth*height/(width*prncfg->fontheight):0;
+	text=g_strdup_printf(_("%d"),MAX(row,0));
+	gtk_label_set_text(GTK_LABEL(label1),text);
+	g_free(text);
+	print_dialog_ok_sensitive(widget,prncfg);
 }
 
 
 /* ܥܥå */
-static void print_dialog_changed(GtkWidget *widget,gpointer user_data)
+static void print_dialog_changed_combo(GtkWidget *widget,gpointer user_data)
 {
 	gchar *name;
 	gint i;
@@ -83,12 +116,11 @@ static void print_dialog_changed(GtkWidget *widget,gpointer user_data)
 		gtk_widget_set_sensitive(spin1,FALSE);
 		gtk_widget_set_sensitive(spin2,FALSE);
 	}
-	print_dialog_ok_sensitive(widget,user_data);
 }
 
 
-/* 饸ܥ */
-static void print_dialog_toggled(GtkWidget *widget,gpointer user_data)
+/* åܥ/饸ܥ */
+static void print_dialog_toggled(GtkWidget *widget,PRNCFG *prncfg)
 {
 	gboolean result;
 
@@ -96,7 +128,7 @@ static void print_dialog_toggled(GtkWidget *widget,gpointer user_data)
 	gtk_widget_set_sensitive(entry0,result);
 	gtk_widget_set_sensitive(entry1,!result);
 	gtk_widget_set_sensitive(button0,!result);
-	print_dialog_ok_sensitive(widget,user_data);
+	print_dialog_ok_sensitive(widget,prncfg);
 }
 
 
@@ -111,6 +143,7 @@ static void print_dialog_clicked_ok(GtkWidget *widget,PRNCFG *prncfg)
 		g_free(prncfg->file);
 		prncfg->file=g_strdup(gtk_entry_get_text(GTK_ENTRY(entry1)));
 	}
+	prncfg->select=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
 	prncfg->column=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
 	prncfg->width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
 	prncfg->height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin2));
@@ -118,6 +151,7 @@ static void print_dialog_clicked_ok(GtkWidget *widget,PRNCFG *prncfg)
 	prncfg->left=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin4));
 	prncfg->right=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin5));
 	prncfg->bottom=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin6));
+    gtk_widget_destroy(dialog);
 	print_clicked_ok=TRUE;
 }
 
@@ -159,7 +193,7 @@ static void print_dialog_clicked_file(GtkWidget *widget,PRNCFG *prncfg)
 }
 
 
-/* ԥܥǥ꥿󤬲줿 */
+/* ȥ꡼/ԥܥǥ꥿󤬲줿 */
 static void print_dialog_activate(GtkWidget *widget,PRNCFG *prncfg)
 {
 	gint left,top,right,bottom;
@@ -220,6 +254,17 @@ gboolean print_dialog(PRNCFG *prncfg)
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
+	/* åܥ */
+	check=gtk_check_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
+													_("ϰϤ(_S)"));
+	gtk_widget_add_accelerator(check,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),prncfg->select);
+	gtk_signal_connect(GTK_OBJECT(check),"toggled",
+												print_dialog_toggled,prncfg);
+	gtk_widget_set_sensitive(check,prncfg->select);
 	/* ȥ꡼ */
 	entry0=gtk_entry_new();
 	entry1=gtk_entry_new();
@@ -232,12 +277,12 @@ gboolean print_dialog(PRNCFG *prncfg)
 	gtk_signal_connect(GTK_OBJECT(entry1),"activate",
 											print_dialog_clicked_ok,prncfg);
 	gtk_signal_connect(GTK_OBJECT(entry0),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_ok_sensitive,prncfg);
 	gtk_signal_connect(GTK_OBJECT(entry1),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_ok_sensitive,prncfg);
 	/* ԥܥ */
 	spin0=gtk_spin_button_new(GTK_ADJUSTMENT(gtk_adjustment_new(prncfg->column,
-													2,G_MAXINT,1,5,0)),0,0);
+													1,G_MAXINT,1,5,0)),0,0);
 	spin1=gtk_spin_button_new(GTK_ADJUSTMENT(gtk_adjustment_new(prncfg->width,
 													1,G_MAXINT,1,5,0)),0,0);
 	spin2=gtk_spin_button_new(GTK_ADJUSTMENT(gtk_adjustment_new(prncfg->height,
@@ -279,19 +324,19 @@ gboolean print_dialog(PRNCFG *prncfg)
 	gtk_signal_connect(GTK_OBJECT(spin6),"activate",
 												print_dialog_activate,prncfg);
 	gtk_signal_connect(GTK_OBJECT(spin0),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_changed_spin,prncfg);
 	gtk_signal_connect(GTK_OBJECT(spin1),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_changed_spin,prncfg);
 	gtk_signal_connect(GTK_OBJECT(spin2),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_changed_spin,prncfg);
 	gtk_signal_connect(GTK_OBJECT(spin3),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_changed_spin,prncfg);
 	gtk_signal_connect(GTK_OBJECT(spin4),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_changed_spin,prncfg);
 	gtk_signal_connect(GTK_OBJECT(spin5),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_changed_spin,prncfg);
 	gtk_signal_connect(GTK_OBJECT(spin6),"changed",
-											print_dialog_ok_sensitive,NULL);
+											print_dialog_changed_spin,prncfg);
 	/* 饸ܥ */
 	radio0=gtk_radio_button_new_with_label(NULL,NULL);
 	radio1=gtk_radio_button_new_with_label_from_widget(
@@ -306,13 +351,15 @@ gboolean print_dialog(PRNCFG *prncfg)
 	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
 									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
 											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",print_dialog_toggled,NULL);
-	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",print_dialog_toggled,NULL);
+	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",
+												print_dialog_toggled,prncfg);
+	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",
+												print_dialog_toggled,prncfg);
 	if (!prncfg->mode)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1),TRUE);
 	/* ٥ */
 	label0=gtk_label_new(NULL);
-	label1=gtk_label_new(_(""));
+	label1=gtk_label_new(NULL);
 	label2=gtk_label_new(NULL);
 	label3=gtk_label_new(NULL);
 	label4=gtk_label_new(NULL);
@@ -356,7 +403,7 @@ gboolean print_dialog(PRNCFG *prncfg)
 	gtk_combo_set_value_in_list(GTK_COMBO(combo),TRUE,FALSE);
 	gtk_editable_set_editable(GTK_EDITABLE(GTK_COMBO(combo)->entry),FALSE);
 	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"changed",
-													print_dialog_changed,NULL);
+											print_dialog_changed_combo,NULL);
 	for (i=0;paper[i].name!=NULL;i++)
 		if (paper[i].width==prncfg->width && paper[i].height==prncfg->height)
 			break;
@@ -367,28 +414,28 @@ gboolean print_dialog(PRNCFG *prncfg)
 
 	/* ե졼ȥܥå */
 	frame0=gtk_frame_new(_("ѻ"));
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),combo,TRUE,TRUE,8);
-	hbox0=gtk_hbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),combo,TRUE,TRUE,0);
+	hbox0=gtk_hbox_new(FALSE,8);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),label2,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin1,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),label3,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin2,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame0),hbox0);
+	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame0),vbox);
 
 	frame1=gtk_frame_new(_("ޡ"));
-	vbox=gtk_vbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	hbox0=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),label4,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),spin3,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
 	hbox0=gtk_hbox_new(FALSE,8);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),label5,FALSE,FALSE,0);
@@ -402,52 +449,51 @@ gboolean print_dialog(PRNCFG *prncfg)
 	hbox0=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),label7,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox0),spin6,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame1),hbox0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame1),vbox);
 
-	vbox=gtk_vbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 
-	hbox0=gtk_hbox_new(FALSE,0);
+	hbox0=gtk_hbox_new(FALSE,8);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spin0,TRUE,TRUE,0);
 	gtk_box_pack_end(GTK_BOX(hbox1),label0,FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,8);
-	gtk_box_pack_end(GTK_BOX(hbox0),label1,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
+	gtk_box_pack_end(GTK_BOX(hbox0),label1,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
 
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),radio0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox0),entry0,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
 
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),radio1,FALSE,FALSE,8);
+	hbox0=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),radio0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox0),entry0,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
+
+	hbox0=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),radio1,FALSE,FALSE,0);
 	hbox1=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),entry1,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),button0,FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
 
-	gtk_box_pack_start(GTK_BOX(vbox),frame0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),frame1,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),frame0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),frame1,FALSE,FALSE,0);
 
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox0),button2,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox0),button1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(vbox),hbox0,FALSE,FALSE,8);
+	hbox0=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox0),button2,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox0),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
 
-	hbox0=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox0),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(dialog),hbox0);
+	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
 	/* ɽ */
 	gtk_widget_set_sensitive(entry0,prncfg->mode);
 	gtk_widget_set_sensitive(entry1,!prncfg->mode);
 	gtk_widget_set_sensitive(button0,!prncfg->mode);
 	gtk_widget_grab_focus(button1);
-	print_dialog_ok_sensitive(NULL,NULL);
+	print_dialog_changed_spin(NULL,prncfg);
 	print_clicked_ok=FALSE;
 
 	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
@@ -457,4 +503,185 @@ gboolean print_dialog(PRNCFG *prncfg)
 
 	return print_clicked_ok;
 }
+
+
+/******************************************************************************
+*                                                                             *
+* ؿ                                                                  *
+*                                                                             *
+******************************************************************************/
+gboolean print_out(TEXTWND *ptw,PRNCFG *prncfg)
+{
+	guchar *c;
+	gint i,x,y,sx,sy,datapos,endpos,line,width,channels,rowstride;
+	FILE *fp;
+	LINEBUF *p;
+	GdkGC *gc;
+	GdkPixmap *pixmap;
+	GdkPixbuf *pixbuf;
+	GdkPoint start,end;
+
+	sx=prncfg->column*prncfg->fontwidth;
+	sy=sx*(prncfg->height-prncfg->left-prncfg->right)
+								/(prncfg->width-prncfg->top-prncfg->bottom);
+	if (ptw->select.x<0 || !prncfg->select) {
+		/* ϰϤʤ٤ư */
+		start.x=start.y=0;
+		end.x=get_width(ptw,ptw->max-1);
+		end.y=ptw->max-1;
+	} else if (ptw->select.y<ptw->cursor.y
+			|| (ptw->select.y==ptw->cursor.y && ptw->select.x<ptw->cursor.x)) {
+		start=ptw->select;
+		end=ptw->cursor;
+	} else {
+		start=ptw->cursor;
+		end=ptw->select;
+	}
+	if (prncfg->mode) {
+		/* ץ */
+		if ((fp=popen(prncfg->printer,"w"))==NULL) {
+			message_box("Text maid",_("ץ󥿤ޤ"),0,
+															_("λ"),NULL);
+			return FALSE;
+		}
+	} else {
+		/* ե */
+		if ((fp=fopen(prncfg->file,"wt"))==NULL) {
+			message_box("Text maid",_("ե뤬ޤ"),0,
+															_("λ"),NULL);
+			return FALSE;
+		}
+	}
+	fputs("%!PS-Adobe-3.0\n",fp);
+	pixmap=gdk_pixmap_new(window->window,sx,sy,-1);
+	pixbuf=gdk_pixbuf_new(GDK_COLORSPACE_RGB,FALSE,8,sx,sy);
+	gc=gdk_gc_new(pixmap);
+	gdk_gc_set_line_attributes(gc,1,
+								GDK_LINE_SOLID,GDK_CAP_BUTT,GDK_JOIN_MITER);
+	for (i=10;i<12;i++)
+		gdk_color_alloc(gdk_colormap_get_system(),
+									(ptw->syscol?system_color:ptw->color)+i);
+	p=get_line_buf(&ptw->start,&ptw->off,start.y);
+	endpos=get_data_pos(ptw,end.x,end.y,FALSE);
+	line=start.y;
+	datapos=get_data_pos(ptw,start.x,start.y,FALSE);
+	/* ܥå */
+	userbreak=TRUE;
+	dialog=abort_dialog(_(""));
+	gtk_grab_add(dialog);
+	while (line<=end.y) {
+		/* ڡ */
+		/* ط */
+		gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+11);
+		gdk_draw_rectangle(pixmap,gc,TRUE,0,0,sx,sy);
+		gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+10);
+		x=y=0;
+		while (y<=sy-ptw->fontheight && line<=end.y) {
+			while (gtk_events_pending())
+				gtk_main_iteration();
+			while (x<sx) {
+				if (datapos>=(line==end.y?endpos:p->length)) {
+					/* Ԥν */
+					datapos=0;
+					line++;
+					p=p->next;
+					if (p==NULL || !p->margin)
+						break;
+				}
+				if (p->text[datapos]=='\t') {
+					/*  */
+					width=(x/ptw->fontwidth/ptw->tab+1)*ptw->tab
+															*ptw->fontwidth-x;
+					if (sx<width+x)
+						break;
+					datapos++;
+				} else if (datapos+charset_length(p->text[datapos])
+																<=p->length) {
+					/* Ⱦ/ */
+					width=ptw->fontwidth*charset_width(ptw->font,
+											p->text+datapos,ptw->fontwidth);
+					if (sx<x+width)
+						break;
+					/* ʸ */
+					gdk_draw_text(pixmap,ptw->font,gc,
+										x,y+ptw->fontascent,p->text+datapos,
+											charset_length(p->text[datapos]));
+					datapos+=charset_length(p->text[datapos]);
+				} else {
+					/* Ⱦ */
+					width=ptw->fontwidth;
+					if (sx<x+width)
+						break;
+					gdk_draw_text(pixmap,ptw->font,gc,
+										x,y+ptw->fontascent,p->text+datapos,1);
+					datapos++;
+				}
+				x+=width;
+			}
+			x=0;
+			y+=ptw->fontheight;
+		}
+		fprintf(fp,
+			"%d %d translate\n"
+			"%d %d scale\n"
+			"%d %d 8 [%d 0 0 %d 0 0]\n"
+			"{currentfile 32 string readhexstring pop}\n"
+			"image\n",
+			prncfg->left,prncfg->bottom,
+			prncfg->width-prncfg->left-prncfg->right,
+			prncfg->height-prncfg->top-prncfg->bottom,
+			sx,sy,sx,sy);
+		gdk_pixbuf_get_from_drawable(pixbuf,pixmap,gdk_colormap_get_system(),
+																0,0,0,0,sx,sy);
+		channels=gdk_pixbuf_get_n_channels(pixbuf);
+		rowstride=gdk_pixbuf_get_rowstride(pixbuf);
+		c=gdk_pixbuf_get_pixels(pixbuf);
+		i=0;
+		switch (channels) {
+			case 1:
+				for (y=sy-1;y>=0;y--)
+					for (x=0;x<sx;x++) {
+						fprintf(fp,"%02x",c[x*channels+y*rowstride]);
+						if (++i%32==0)
+							fputc('\n',fp);
+					}
+				break;
+			case 3:
+			case 4:
+				for (y=sy-1;y>=0;y--)
+					for (x=0;x<sx;x++) {
+						fprintf(fp,"%02x",(c[x*channels+y*rowstride]*77
+										+c[x*channels+y*rowstride+1]*150
+										+c[x*channels+y*rowstride+2]*29)/256);
+						if (++i%32==0)
+							fputc('\n',fp);
+					}
+				break;
+			default:
+				for (y=0;y<sy;y++)
+					for (x=0;x<sx;x++) {
+						fputs("ff",fp);
+						if (++i%32==0)
+							fputc('\n',fp);
+					}
+		}
+		fputs("showpage\n",fp);
+		if (!userbreak)
+			goto loop;
+	}
+	loop:
+	/* λ */
+	gtk_grab_remove(dialog);
+    gtk_widget_destroy(dialog);
+	gdk_gc_destroy(gc);
+	gdk_pixbuf_unref(pixbuf);
+	gdk_pixmap_unref(pixmap);
+	if (prncfg->mode)	/* ץ */
+		pclose(fp);
+	else				/* ե */
+		fclose(fp);
+	return TRUE;
+}
+
+
 #endif
