@@ -36,9 +36,9 @@ static GtkWidget *check0,*check1,*check2,*check3,*check4,*check5;
 static GtkWidget *check6,*check7,*check8,*check9,*check10,*check11;
 static GtkWidget *clist,*entry0,*entry1,*label,*spin0,*spin1;
 static gchar *color_name[12]={N_("ʸ"),N_("ط"),N_("ȥ륳"),
-		N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
-		N_("ޡ"),N_("å"),N_("򤵤줿ʸ"),
-		N_("򤵤줿ط"),N_("ʸ()"),N_("ȥ륳()")};
+					N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
+					N_("ޡ"),N_("å"),N_("򤵤줿ʸ"),
+					N_("򤵤줿ط"),N_("ʸ()"),N_("ط()")};
 
 
 /* OKܥɽ/ɽȽ */
@@ -536,69 +536,62 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_signal_connect(GTK_OBJECT(spin1),"changed",
 											property_dialog_ok_sensitive,NULL);
 	/* ե졼ȥܥå */
-	tbox=gtk_hbox_new(FALSE,0);
+	tbox=gtk_hbox_new(FALSE,8);
 	if (entry0!=NULL && entry1!=NULL) {
 		hbox=gtk_hbox_new(FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),
 									gtk_label_new(_("ʸ")),FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),entry0,TRUE,TRUE,0);
-		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,8);
+		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
 		hbox=gtk_hbox_new(FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),
 									gtk_label_new(_("ĥ")),FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),entry1,TRUE,TRUE,0);
-		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,8);
+		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
 	} else {
-		gtk_box_pack_start(GTK_BOX(tbox),label,TRUE,TRUE,8);
+		gtk_box_pack_start(GTK_BOX(tbox),label,TRUE,TRUE,0);
 	}
 
 	frame0=gtk_frame_new(_("ɽ"));
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),check0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),check1,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),check2,FALSE,FALSE,8);
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
-	gtk_container_add(GTK_CONTAINER(frame0),vbox);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
+	gtk_box_pack_start(GTK_BOX(hbox),check0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check1,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check2,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame0),hbox);
 
 	frame1=gtk_frame_new(_("ޡ"));
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),spin0,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),check3,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),check4,FALSE,FALSE,8);
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame1),vbox);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
+	gtk_box_pack_start(GTK_BOX(hbox),spin0,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check3,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check4,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame1),hbox);
 
 	frame2=gtk_frame_new(_(""));
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),spin1,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),check5,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),check6,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),check7,FALSE,FALSE,8);
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame2),vbox);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
+	gtk_box_pack_start(GTK_BOX(hbox),spin1,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check5,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check6,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check7,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame2),hbox);
 
 	frame3=gtk_frame_new(_("¸"));
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),check8,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),check9,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),vbox,FALSE,FALSE,8);
-	gtk_container_add(GTK_CONTAINER(frame3),hbox);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),check8,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),check9,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame3),vbox);
 
 	frame4=gtk_frame_new(_(""));
-	vbox=gtk_vbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),check10,FALSE,FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),scroll,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),check10,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame4),vbox);
 
 	vbox=gtk_vbox_new(FALSE,8);
@@ -607,22 +600,23 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(vbox),frame2,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),frame3,FALSE,FALSE,0);
 
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),vbox,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),frame4,TRUE,TRUE,8);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),vbox,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),frame4,FALSE,FALSE,0);
 
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),tbox,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,8);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),tbox,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,0);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,0);
 	if (button2!=NULL)
-		gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,8);
+		gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,0);
 	if (check11!=NULL)
-		gtk_box_pack_start(GTK_BOX(hbox),check11,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button4,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+		gtk_box_pack_start(GTK_BOX(hbox),check11,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button4,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
