@@ -98,49 +98,51 @@ gint repinfo_dialog(REPINFO *ri)
 	GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
 	/* ե졼ȥܥå */
 	tbox=gtk_vbox_new(FALSE,0);
-	hbox=gtk_hbox_new(FALSE,0);
+	gtk_container_set_border_width(GTK_CONTAINER(tbox),8);
+	hbox=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_start(GTK_BOX(hbox),
-								gtk_label_new(_("ʸ")),FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(ri->src),TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
+								gtk_label_new(_("ʸ")),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(ri->src),TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
+	hbox=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_start(GTK_BOX(hbox),
-								gtk_label_new(_("ִʸ")),FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(ri->dst),TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
+								gtk_label_new(_("ִʸ")),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(ri->dst),TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
+	hbox=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_start(GTK_BOX(hbox),
-								gtk_label_new(_("ִϰ")),FALSE,FALSE,8);
+								gtk_label_new(_("ִϰ")),FALSE,FALSE,0);
 	text=g_strdup_printf(_("(%d,%d)-(%d,%d)"),
 						ri->start.x+1,ri->start.y+1,ri->end.x+1,ri->end.y+1);
-	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(text),TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(text),TRUE,TRUE,0);
 	g_free(text);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
+
 	frame0=gtk_frame_new(_("ץ"));
-	hbox=gtk_hbox_new(FALSE,0);
-	vbox=gtk_vbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),
 						gtk_label_new(ri->ignorecase?_("/ʸ̤")
-								:_("/ʸ̤ʤ")),FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame0),hbox);
+								:_("/ʸ̤ʤ")),FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame0),vbox);
+
 	frame1=gtk_frame_new(_("ִ"));
-	hbox=gtk_hbox_new(FALSE,0);
-	vbox=gtk_vbox_new(FALSE,0);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),
-					gtk_label_new(ri->arrow?_(""):_("")),FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame1),hbox);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),frame0,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),frame1,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button2,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(tbox),hbox,FALSE,FALSE,8);
+					gtk_label_new(ri->arrow?_(""):_("")),FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame1),vbox);
+
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),frame0,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),frame1,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button2,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),tbox);
 
 	/* ɽ */
