@@ -73,7 +73,7 @@ GdkColor system_color[12]={	{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
 							{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
 							{0,0x8000,0x8000,0x8000},{0,0xa000,0xa000,0xa000},
 							{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000},
-							{0,0x0000,0x0000,0x0000},{0,0x8000,0x8000,0x8000}};
+							{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff}};
 GtkTargetEntry targets[3]={			/* Text maid󶡲ǽʥ쥯 */
 	{"STRING",       0,TARGET_STRING},
 	{"TEXT",         0,TARGET_TEXT}, 
