@@ -29,7 +29,11 @@
 #include "intl.h"
 
 
+#ifdef USE_GDKPIXBUF
+#define MENUFILE 12
+#else
 #define MENUFILE 10
+#endif
 
 
 typedef struct ftype {
@@ -84,7 +88,8 @@ typedef struct textwnd {
 	gboolean uline;				/* TRUE:ֲɽ */
 	gboolean vline;				/* TRUE:ֽɽ */
 	gint ft_id;					/* ե륿פID(-1:̵°) */
-	gint fontsize;				/* եȤβ */
+	gint fontwidth;				/* եȤβ */
+	gint fontheight;			/* եȤι⤵ */
 	gint fontascent;			/* եȤΥȤι⤵ */
 	gint margin;				/* ޡο */
 	gint max;					/* Կ */
@@ -104,10 +109,11 @@ typedef struct textwnd {
 	GtkWidget *drawing;			/* ΰ */
 	GtkWidget *hscroll;			/* ʿС */
 	GtkWidget *vscroll;			/* ľС */
+	GtkWidget *label;			/* ֤Υ٥ */
 	GtkWidget *menu_item;		/* ˥塼Υɥι */
 } TEXTWND;
 typedef struct comm {
-	gchar *str;
+	gchar *arg;
 	gint leng,init_line;
 	gint32 pid;
 	struct comm *prev,*next;
@@ -125,8 +131,10 @@ extern gboolean caret;					/* åȤη */
 extern gboolean ins;					/* TRUE:,FALSE: */
 extern gboolean newfile;				/* TRUE:ե,FALSE:ʤ */
 extern gboolean second;					/* TRUE:,FALSE:¸ */
-extern gchar *clipboard_text;			/* åץܡɤΥƥ */
 extern gchar *hisfile[10];				/* ե */
+extern gchar *openpath;					/* Υѥ */
+extern gchar *savepath;					/* ̾դ¸Υѥ */
+extern gchar *clipboard_text;			/* åץܡɤΥƥ */
 extern gint def_width,def_height;		/* ǥեȤΥɥΥ */
 extern gint ftnum;						/* ե륿פο */
 extern gint history;					/* ե */
@@ -148,6 +156,7 @@ extern GtkItemFactory *item_factory_menu;	/* ˥塼 */
 extern GtkItemFactory *item_factory_popup;	/* ݥåץå */
 extern GdkFont *system_font;
 extern GdkColor system_color[12];
+extern GtkTargetEntry targets[3];		/* Text maid󶡲ǽʥ쥯 */
 
 
 #endif
