@@ -156,25 +156,21 @@ gboolean valchr_dialog(gchar *valchr)
 									valchr_dialog_clicked_radio,(gpointer)8);
 	/* ե졼ȥܥå */
 	frame=gtk_frame_new(_(""));
-	vbox=gtk_vbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),radio1,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),radio2,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),vbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(frame),hbox);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),radio1,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),radio2,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame),vbox);
 
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),entry,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),frame,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),frame,TRUE,TRUE,0);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
 	/* ɽ */
